==> cobs-0.6.tgz: cobs-0.06/com.php <==
<? 
 require("config.php");
 require("dbconfig.php");
 require("ref.php");
 require("strong.php");
 /**** @ܼ ********/
  //QueryO
 $chsec=$chap*1000+$sec;
 $QUERY="select engs,bchap,bsec,echap,esec,txt,id from $book where engs='$engs' and (bchap*1000+bsec)<= $chsec and (echap*1000+esec)>= $chsec"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //d߸ƪY
 $THEADER=array("`","rq");
  //C@
 $PGNUM=50;
 $PROGRAM="com.php";
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echo "@ $numrow AƤӦhFAЭקd߱AdI";
	exit;
   }
 if ($numrow==0)
   {
   	echo "$book ѤdơAЭקd߱AdI";
	exit;
   }
 /******** LX ********/
 echo "<FONT COLOR=$COLOR><center><table $tabout>\n";
      $ARAW=db_fetch_row($result,0); //Ū@O
 /***********/
 $chsec=$ARAW[1]*1000+$ARAW[2];
 $QUERY1="select bchap,bsec from $book where engs='$engs' and (bchap*1000+bsec)> $chsec order by bchap*1000+bsec limit 1 "; 
 $result1=db_exec($db_conn,$QUERY1);
 if (!$result1){
                        echo "Ʈwd߿~AO $QUERY1 !";
                        exit;
 }
 $numrow1=db_NumRows($result1);  
 /****e*******/
 $chsec=$ARAW[3]*1000+$ARAW[4];
 $QUERY2="select echap,esec from $book where engs='$engs' and  (echap*1000+esec) < $chsec order by echap*1000+esec DESC limit 1"; 
 $result2=db_exec($db_conn,$QUERY2);
 if (!$result2){
                        echo "Ʈwd߿~AO $QUERY2 !";
                        exit;
 }
 $numrow2=db_NumRows($result2);  
	$show="$ARAW[0] $ARAW[1]:$ARAW[2] - $ARAW[3]:$ARAW[4]";
        $special=htmlspecialchars($show);//SrBz
      echo "<tr><td align=center>$special &nbsp;&nbsp;<a href=\"$PROGRAM?book=$book&engs=$engs&chap=0&sec=0\">I</a>"; //s
	if ($numrow2>0) //W@
	{
          $ARAW2=db_fetch_row($result2,0); //Ū@O
          echo "&nbsp;&nbsp;<a href=\"$PROGRAM?book=$book&engs=$engs&chap=$ARAW2[0]&sec=$ARAW2[1]\">W@</a>"; //s
        }
	if ($numrow1>0) //U@
	{
          $ARAW1=db_fetch_row($result1,0); //Ū@O
          echo "&nbsp;&nbsp;<a href=\"$PROGRAM?book=$book&engs=$engs&chap=$ARAW1[0]&sec=$ARAW1[1]\">U@</a>"; //s
        }
      echo "</td></tr>\n";
	$ARAW[5]=procstrong(1,$ARAW[5]);
	$special1=ref($ARAW[5],$ARAW[0],$ARAW[1],$db_conn,"unv");
      echo "<tr><td><pre>$special1</pre></td></tr>\n";
      //$special=htmlspecialchars($ARAW[5]);//SrBz
   echo "</table>\n";
   echo "<a href=\"$RETURNADD1\">sd</a></center><br>\n";
?>

==> cobs-0.7.tgz: cobs-0.7/com.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 require("ref.php");
 require("strong.php");
/************* GET ܼ ***************/
  $book=(int) $_REQUEST["book"];//
  $engs=$_REQUEST["engs"];//g
  $chap=(int) $_REQUEST["chap"];//
  $sec=(int) $_REQUEST["sec"];//`
  //QueryO
 $chsec=$chap*1000+$sec;
 $QUERY="select engs,bchap,bsec,echap,esec,txt,id from comment where tag=$book and engs='$engs' and (bchap*1000+bsec)<= $chsec and (echap*1000+esec)>= $chsec"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //d߸ƪY
 $THEADER=array("`","rq");
  //C@
 $PGNUM=50;
 $PROGRAM="com.php";
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echo "@ $numrow AƤӦhFAЭקd߱AdI";
	exit;
   }
 if ($numrow==0)
   {
   	echo "$book ѤdơAЭקd߱AdI";
	exit;
   }
 /******** LX ********/
 echo "<FONT COLOR=$COLOR><center><table $tabout>\n";
      $ARAW=db_fetch_row($result,0); //Ū@O
 /***********/
 $chsec=$ARAW[1]*1000+$ARAW[2];
 $QUERY1="select bchap,bsec from comment where tag=$book and engs='$engs' and (bchap*1000+bsec)> $chsec order by bchap*1000+bsec limit 1 "; 
 $result1=db_exec($db_conn,$QUERY1);
 if (!$result1){
                        echo "Ʈwd߿~AO $QUERY1 !";
                        exit;
 }
 $numrow1=db_NumRows($result1);  
 /****e*******/
 $chsec=$ARAW[3]*1000+$ARAW[4];
 $QUERY2="select echap,esec from comment where tag=$book and engs='$engs' and  (echap*1000+esec) < $chsec order by echap*1000+esec DESC limit 1"; 
 $result2=db_exec($db_conn,$QUERY2);
 if (!$result2){
                        echo "Ʈwd߿~AO $QUERY2 !";
                        exit;
 }
 $numrow2=db_NumRows($result2);  
	$show="$ARAW[0] $ARAW[1]:$ARAW[2] - $ARAW[3]:$ARAW[4]";
        $special=htmlspecialchars($show);//SrBz
      echo "<tr><td align=center>$special &nbsp;&nbsp;<a href=\"$PROGRAM?book=$book&engs=$engs&chap=0&sec=0\">I</a>"; //s
	if ($numrow2>0) //W@
	{
          $ARAW2=db_fetch_row($result2,0); //Ū@O
          echo "&nbsp;&nbsp;<a href=\"$PROGRAM?book=$book&engs=$engs&chap=$ARAW2[0]&sec=$ARAW2[1]\">W@</a>"; //s
        }
	if ($numrow1>0) //U@
	{
          $ARAW1=db_fetch_row($result1,0); //Ū@O
          echo "&nbsp;&nbsp;<a href=\"$PROGRAM?book=$book&engs=$engs&chap=$ARAW1[0]&sec=$ARAW1[1]\">U@</a>"; //s
        }
      echo "</td></tr>\n";
	$ARAW[5]=procstrong(1,$ARAW[5]);
	$special1=ref($ARAW[5],$ARAW[0],$ARAW[1],$db_conn,"unv");
      echo "<tr><td><pre>$special1</pre></td></tr>\n";
      //$special=htmlspecialchars($ARAW[5]);//SrBz
   echo "</table>\n";
   echo "<a href=\"$RETURNADD1\">sd</a></center><br>\n";
?>
